clear
set mem 200m
set more off
capture log close
global dataloc="W:\NYOSHIDA\data 2004-05"

log using "$dataloc\expend.log", replace

** Roster **
* to obtain psucode and hhsize *

use "$dataloc\data\pslmB.dta", clear
count
isid hhcode serialno
keep hhcode psucode serialno age
format hhcode %11.0f

gen adult=0.8 if age<18
recode adult .=1

egen eqadults=sum(adult), by(hhcode)
egen hhsize=count(serialno), by(hhcode)

label var eqadults "Number of equivalent adults counting members & nonmembers"
label var hhsize "Number of people in hh counting members & nonmembers"

sort hhcode
by hhcode: keep if _n==1
count

compress
save "$dataloc\data\exp\hhsize.dta", replace


** Program to calculate the annual expenditure of the household
*first, fortnightly food consumption data

use "$dataloc\data\pslmL1_3.dta", clear
count
isid hhcode serialno
rename serialno itc
drop if itc==1001|itc==1002|itc==1003|itc==1000
drop if itc>=2000
count
tab itc
*dropping page and Part A totals, we will compute our own totals
 
sort hhcode itc
* to check if some households have duplicate information on any item

quietly by hhcode itc: gen dup = cond(_N==1,0,_n)
tab dup /* No duplication */
drop if dup>=2
sort hhcode itc
drop dup
collapse (sum) s6q02=paid_v s6q04=wage_v s6q06=own_v s6q08=tran_v, by (hhcode)

sort hhcode

egen int food_cnt=robs(s6q*)
* assert food_cnt!=0
egen double food=rsum(s6q*) if food_cnt>0
drop food_cnt
label var s6q02 "Total food expend (paid and consumed)"
label var s6q04 "Total food expend (unpaid and consumed: wages in kind)"
label var s6q06 "Total food expend (unpaid and consumed: own produced)"
label var s6q08 "Total food expend (unpaid and consumed: assistance, gifts, dowry)"
label var food "Total food expend (sum of s6q02..08)"

gen fort=1
label var fort "=1 if fortnightly, 0 monthly"
compress
sort hhcode
save "$dataloc\data\exp\exp-foodF.dta", replace


*Now, monthly food consumption data

use "$dataloc\data\pslmL1_3.dta", clear
count
isid hhcode serialno
rename serialno itc
drop if itc<=2002
drop if itc>=2700
count

tab itc
* to check if some households have duplicate information on any item
sort hhcode itc
quietly by hhcode itc: gen dup = cond(_N==1,0,_n)
tab dup /* No duplication */
drop if dup>=2
sort hhcode itc
drop dup

collapse (sum) s6q02=paid_v s6q04=wage_v s6q06=own_v s6q08=tran_v, by (hhcode)
sort hhcode

egen int food_cnt=robs(s6q*)
assert food_cnt!=0
egen double food=rsum(s6q*) if food_cnt>0
drop food_cnt
gen fort=0
label var fort "=1 if fortnightly, 0 monthly"
compress
sort hhcode

append using "$dataloc\data\exp\exp-foodF.dta"
replace s6q02=2*s6q02 if fort==1
replace s6q04=2*s6q04 if fort==1
replace s6q06=2*s6q06 if fort==1
replace s6q08=2*s6q08 if fort==1
replace food=2*food if fort==1
sort hhcode fort
collapse (sum) s6q02 s6q04 s6q06 s6q08 food, by (hhcode)
label var s6q02 "Total monthly food expend (paid and consumed)"
label var s6q04 "Total monthly food expend (unpaid and consumed: wages in kind)"
label var s6q06 "Total monthly food expend (unpaid and consumed: own produced)"
label var s6q08 "Total monthly food expend (unpaid and consumed: assistance, gifts, dowry)"
label var food "Total food expend (sum of s6q02..08)"

*variables s6q02..s6q08 and food are aggregates of monthly food expend (from sect6b.dta)
*and fortnightly food expend (from sect6a.dta)-converted into monthly figures

keep food hhcode
* keep only total food expend (food) *

sort hhcode
save "$dataloc\data\exp\exp-foodM.dta", replace
*This file has all food expenditures (monthly, and fortnightly-converted into monthly)


*****************************************
* Now, the non-food monthly expenditures
*****************************************

use "$dataloc\data\pslmL1_3.dta", clear
count
isid hhcode serialno
rename serialno itc
*Keep only non-food expenditures
keep if itc>=2701 & itc<4000
count
tab itc

sort hhcode itc
quietly by hhcode itc: gen dup = cond(_N==1,0,_n)
tab dup /* No duplication */
drop if dup>=2
gen byte categ=1 if itc>=2701 & itc<=2710
replace categ=2 if itc>=2801 & itc<=2805
replace categ=3 if itc>=2901 & itc<=2903
replace categ=4 if itc>=3001 & itc<=3003
drop itc dup
sort hhcode categ

forvalues i=1(1)4 {
  egen double s6bqt`i'02 = sum(paid_v) if categ==`i', by(hhcode)
  egen double s6bqt`i'04 = sum(wage_v) if categ==`i', by(hhcode)
  egen double s6bqt`i'06 = sum(own_v) if categ==`i', by(hhcode)
  egen double s6bqt`i'08 = sum(tran_v) if categ==`i', by(hhcode)
  compress
}

sort hhcode categ

foreach var of varlist s6bqt102 - s6bqt408 {
  quietly recode `var' 0=.
}

collapse (mean) s6bqt*, by(hhcode)

egen int fuelM_cnt=robs(s6bqt1*)
* assert fuelM_cnt!=0
egen double fuelM=rsum(s6bqt1*) if fuelM_cnt>0
drop fuelM_cnt

egen double pcarartM=rsum(s6bqt2*)

egen double pcarserM=rsum(s6bqt3*)

egen double laundryM=rsum(s6bqt4*)

quietly for var s6bqt102 - s6bqt408: recode X .=0

label var fuelM "Total value of Fuel and lighting"
label var pcarartM "Total value of Personal care articles"
label var pcarserM "Total value of Personal care services"
label var laundryM "Total value of Household laundry, cleaning and paper articles"

keep fuelM pcarartM pcarserM laundryM hhcode
* keep only total values *

compress
sort hhcode

save "$dataloc\data\exp\exp-nonfoodM_f.dta", replace


* Monthly Non-Durable expenditures in a male file *

use "$dataloc\data\pslmL1_3.dta", clear
count
isid hhcode serialno
rename serialno itc
keep if itc>=4101 & itc<=4406
tab itc
* Check duplication *

sort hhcode itc
quietly by hhcode itc: gen dup = cond(_N==1,0,_n)
tab dup /* No duplication */
drop if dup>=2

gen byte categ=1 if itc>=4101 & itc<=4109
replace categ=2 if itc>=4201 & itc<=4203
replace categ=3 if itc>=4301 & itc<=4304
replace categ=4 if itc>=4401 & itc<=4406
drop itc dup
sort hhcode categ

forvalues i=1(1)4 {
  egen double s6cqt`i'02 = sum(paid_v) if categ==`i', by(hhcode)
  egen double s6cqt`i'04 = sum(wage_v) if categ==`i', by(hhcode)
  egen double s6cqt`i'06 = sum(own_v) if categ==`i', by(hhcode)
  egen double s6cqt`i'08 = sum(tran_v) if categ==`i', by(hhcode)
  compress
}

sort hhcode categ

foreach var of varlist s6cqt102 - s6cqt408 {
  quietly recode `var' 0=.
}

collapse (mean) s6cqt*, by(hhcode)

egen double tobaccoM=rsum(s6cqt1*)
egen double recreatM=rsum(s6cqt2*)
egen double ptranspM=rsum(s6cqt3*)
egen double othmissM=rsum(s6cqt4*)

foreach var of varlist s6cqt102 - s6cqt408 {
  quietly recode `var' .=0
}

label var tobaccoM "Total value of tobacco and chewing products"
label var recreatM "Total value of Recreation & reading"
label var ptranspM "Total value of Personal Transport and travelling"
label var othmissM "Total value of Other Miscellaneous Household expenses"

keep tobaccoM recreatM ptranspM othmissM hhcode
* keep only total values of each item *

compress
sort hhcode

save "$dataloc\data\exp\exp-nonfoodM_m.dta", replace

merge hhcode using "$dataloc\data\exp\exp-nonfoodM_f.dta"
tab _merge
drop _merge
sort hhcode
save "$dataloc\data\exp\exp-nonfoodM.dta", replace





*Now, the Yearly Non-Durable expenditures
*This file will be divided into 2 parts, since it becomes too large
*First Part:

use "$dataloc\data\pslmL4_5.dta", clear
rename serialno itc
keep if itc>=5601 & itc<=5904
tab itc
* Focus on items in the second pate of Section 6 M Household Expenditures Part D *
*automatically drops page and part C totals, since we will compute our own totals

sort hhcode itc
quietly by hhcode itc: gen dup = cond(_N==1,0,_n)
tab dup /* no duplication */
drop if dup>=2
sort hhcode itc
drop dup

gen byte categ=6  if itc>5600 & itc<5700
replace categ=7  if itc>5700 & itc<5800
replace categ=8  if itc>5800 & itc<5900
replace categ=9  if itc==5901
replace categ=10 if itc>5901 & itc<=5904

drop itc
sort hhcode categ

local i = 6
while `i' < 11 {
egen double s6dqt`i'2 = sum(paid_v) if categ==`i', by(hhcode)
egen double s6dqt`i'4 = sum(wage_v) if categ==`i', by(hhcode)
egen double s6dqt`i'6 = sum(own_v) if categ==`i', by(hhcode)
egen double s6dqt`i'8 = sum(tran_v) if categ==`i', by(hhcode)
compress
local i = `i' + 1
}
sort hhcode categ
quietly for var s6dqt62 - s6dqt108: recode X 0=.
collapse (mean) s6dqt*, by(hhcode)

egen double medcareY=rsum(s6dqt6*)
egen double recreatY=rsum(s6dqt7*)
egen double eduprofY=rsum(s6dqt8*)
egen double taxfineY=rsum(s6dqt9*)
egen double othndurY=rsum(s6dqt10*)

keep medcareY recreatY eduprofY taxfineY othndurY hhcode

compress
sort hhcode
save "$dataloc\data\exp\exp-nondurabY.dta", replace

*Now, the second part of the yearly non-durables dataset

use "$dataloc\data\pslmL4_5.dta", clear
rename serialno itc
drop if itc==5000 | itc==5001 | itc==5002
*dropping page and part C totals, since we will compute our own totals

drop if itc>=5600
tab itc
* drop items included in the first part of the yearly non-durables dataset *

sort hhcode itc
quietly by hhcode itc: gen dup = cond(_N==1,0,_n)
tab dup
drop if dup>=2
sort hhcode itc
drop dup

* to check if some households have duplicate information on rent and imputed rent
gen byte flag1=(itc>=5401 & itc<=5404)
sort hhcode flag1 itc
quietly by hhcode flag1: gen dup = cond(_N==1,0,_n)

tab dup if flag1==1

* there are 22 households with duplicate information
* we will take just the first observation within the household: 1st priority: house rent,
* 2nd, subsidized house rent, 3rd, rent-free accommodation and 4th, owner-occupied housing
* these priorities should be changed to check if aggregate figures change, and by how much
drop if flag1==1 & dup>1
drop flag1 dup

drop if itc==5407 /* drop housing tax */
sort hhcode itc
* the category House rent and housing expenses wiil exclude itc=5407 (House & Property Tax)
* Questionnaire has a wrong number for house & property tax *

* Check info on housing rents *
gen dum=(paid_v>0 & paid_v~=.) if itc==5401
tab dum if itc==5401
sum paid_v if itc==5401
table province urbrural if itc==5401, c(m paid_v)
drop dum

gen dum=(wage_v>0 & wage_v~=.) if itc==5402
tab dum if itc==5402
sum wage_v if itc==5402
drop dum

gen dum=(wage_v>0 & wage_v~=.) if itc==5403
tab dum if itc==5403
sum wage_v if itc==5402
drop dum

gen dum=(own_v>0 & own_v~=.) if itc==5404
tab dum if itc==5404
sum own_v if itc==5404
table province urbrural if itc==5404, c(n own_v)
table province urbrural if itc==5404, c(m own_v)
drop dum

gen dum=(paid_v>0 & paid_v~=.) if itc==5405
tab dum if itc==5405
drop dum

gen dum=(paid_v>0 & paid_v~=.) if itc==5406
tab dum if itc==5406
drop dum

******

gen byte categ=1 if itc>5100 & itc<5200
replace categ=2  if itc>5200 & itc<5300
replace categ=3  if itc>5300 & itc<5400
replace categ=4  if itc>5400 & itc<5500
replace categ=5  if itc>5500 & itc<5600

drop itc
sort hhcode categ

local i = 1
while `i' < 6 {
egen double s6dqt`i'2 = sum(paid_v) if categ==`i', by(hhcode)
egen double s6dqt`i'4 = sum(wage_v) if categ==`i', by(hhcode)
egen double s6dqt`i'6 = sum(own_v) if categ==`i', by(hhcode)
egen double s6dqt`i'8 = sum(tran_v) if categ==`i', by(hhcode)
compress
local i = `i' + 1
}
sort hhcode categ
quietly for var s6dqt12 - s6dqt58: recode X 0=.
collapse (mean) s6dqt*, by(hhcode)

egen double clothY=rsum(s6dqt1*)
egen double footwY=rsum(s6dqt2*)
egen double pereffY=rsum(s6dqt3*)
egen double housingY=rsum(s6dqt4*)
egen double chinawY=rsum(s6dqt5*)

keep clothY footwY pereffY housingY chinawY hhcode
compress
sort hhcode

append using "$dataloc\data\exp\exp-nondurabY.dta"
sort hhcode

quietly for var clothY - othndurY: recode X .=0
collapse (sum) clothY-othndurY, by (hhcode)

label var clothY "Total value of Clothing (nondurable)"
label var footwY "Total value of Footwear and Repairs (nondurable)"
label var pereffY "Total value of Personal Effects (nondurable)"
label var housingY "Total value of Housing (nondurable)"
label var chinawY "Total value of Chinaware, Earthenware, etc. (nondurable)"
label var medcareY "Total value of Medical Care (nondurable)"
label var recreatY "Total value of Recreational Activities(nondurable)"
label var eduprofY "Total value of Edu and Professional expend(nondurable)"
label var taxfineY "Total value of taxes and fines expend(nondurable)"
label var othndurY "Total value of Other yearly expend on nondurables,excl.tax & fines"
sort hhcode
compress
save "$dataloc\data\exp\exp-nondurabY.dta", replace

****************************************
*Now, the Yearly Durable Expenditures **
****************************************

use "$dataloc\data\pslmL4_5.dta", clear
rename serialno itc

keep if itc>6100 & itc<6600
*dropping "part D total", since we will compute our own totals

sort hhcode itc
quietly by hhcode itc: gen dup = cond(_N==1,0,_n)
tab dup
drop if dup>=2
sort hhcode itc
drop dup

gen byte categ=1 if itc>6100 & itc<6200
replace categ=2  if itc>6200 & itc<6300
replace categ=3  if itc>6300 & itc<6400
replace categ=4 if itc>=6401 & itc<=6404
replace categ=5 if itc==6405
replace categ=6  if itc>6500 & itc<6600
drop itc
sort hhcode categ

local i = 1
while `i' < 7 {
egen double s6eqt`i'02 = sum(paid_v) if categ==`i', by(hhcode)
egen double s6eqt`i'04 = sum(wage_v) if categ==`i', by(hhcode)
egen double s6eqt`i'06 = sum(own_v) if categ==`i', by(hhcode)
egen double s6eqt`i'08 = sum(tran_v) if categ==`i', by(hhcode)
compress
local i = `i' + 1
}
sort hhcode categ
quietly for var s6eqt102 - s6eqt608: recode X 0=.
collapse (mean) s6eqt*, by(hhcode)

egen double dghhtexY=rsum(s6eqt1*)
egen double dgchinaY=rsum(s6eqt2*)
egen double dgfurnY=rsum(s6eqt3*)
egen double dgoheffY=rsum(s6eqt4*)
egen double dgsheffY=rsum(s6eqt5*)
egen double dgmiscY=rsum(s6eqt6*)

label var dghhtexY "Total value of hh textiles & personal effects (durable)"
label var dgchinaY "Total value of Chinaware, silverware, etc. (durable)"
label var dgfurnY "Total value of Furniture, Fixture and Furnishing(durable)"
label var dgoheffY "Total value of Other HH Effects(durable)excl.service & repair"
label var dgsheffY "Total expend on service & repair of HH Effects(durable)"
label var dgmiscY "Total value of miscell yearly expend on durables"

keep dghhtexY dgchinaY dgfurnY dgoheffY dgsheffY dgmiscY hhcode
compress
sort hhcode

save "$dataloc\data\exp\exp-durabY.dta", replace


* To merge all the files into one
* We will have 2 files: one with the main components of expenditure and
* their breakdown (typ:1,2,3,4) and other with just the main components

*To re-compute expenditure (and thus poverty figures) with different price indices 
*(e.g.paaschz) and weights, re-run the program after making the necessary changes 
*from this point onwards

use "$dataloc\data\exp\exp-foodM.dta", clear

merge hhcode using "$dataloc\data\exp\exp-nonfoodM.dta"
tab _merge
drop _merge
sort hhcode

merge hhcode using "$dataloc\data\exp\exp-nondurabY.dta"
tab _merge
drop _merge
sort hhcode

merge hhcode using "$dataloc\data\exp\exp-durabY.dta"
tab _merge
drop _merge
sort hhcode

merge hhcode using "$dataloc\data\exp\hhsize.dta"
tab _merge
drop _merge
sort psucode

merge psucode using "$dataloc\data\weight.dta"
tab _merge
drop _merge
sort hhcode

sort hhcode

* create population weight *
gen popwt=weight*hhsize

* we recode all the expenditures from zero to missing
quietly for var food - dgmiscY: recode X 0=.

* we change all the yearly expenditures to monthly 
quietly for var clothY - dgmiscY: replace X=X/12

* we calculate the total expenditure
egen double ntexpend=rsum(food-eduprofY othndurY dgsheffY) if food~=. /* if food exp=0, drop it */
label var ntexpend "Total nominal monthly expend of the hh excl. tax and fine, and durable goods"
gen nonfood=ntexpend-food
label var nonfood "nonfood expenditure"
gen r_food=food/ntexpend
label var r_food "ratio of food expenditure"
sum r_food food ntexpend [aw=popwt]
sum hhsize [aw=weight]

sort hhcode
compress
save "$dataloc\data\exp\nom_expendt.dta", replace

* add area variables *
use "$dataloc\data\pslmB.dta", clear
 drop sex res rel age marital
egen tag=tag( hhcode)
keep if tag==1
drop sectname serialno tag
sort hhcode
save temp, replace


use "$dataloc\data\exp\nom_expendt.dta", clear
sort hhcode
merge hhcode using temp
tab _m
drop _m

* Compute share of each times *
quietly for var food - dgmiscY: recode X .=0
drop r_food
quietly for var food - dgmiscY: gen r_X=X/ntexpend

capture log close
log using "$dataloc\data\exp\nominal expenditure.smcl", replace
* Analysis on nominal expenditures *
 sum food- dgmiscY ntexpend
 sum food- dgmiscY ntexpend if urbrural==1
 sum food- dgmiscY ntexpend if urbrural==2
 sum r_food- r_dgmiscY 
 sum r_food- r_dgmiscY if urbrural==1
 sum r_food- r_dgmiscY if urbrural==2
 table urbrural, c(m food m nonfood m r_food)
 gen peanexp=ntexpend/eqadults
 kdensity peanexp [aweight=weight] if ntexpend<=4000, epanechnikov xline(878.64)
 log close





