clear
set mem 200m
set more off
capture log close
global dataloc="C:\Documents and Settings\wb236343\My Documents\Pakistan\PSLM\data 2004-05"

log using "$dataloc\data\price\paasche_fbs.log", replace

*******************************************************************************************************************************************
* This program is used to do the same spatial price adjustment as "Poverty in the 1990s" *
** Program to calculate the Paasche Index by household
** 1. To obtain the budget share of each food item per household
** 2. To obtain the implicit price paid for each food item per household
** 3. To obtain the reference price (price of each food item at a national level), take the median not the mean
** 4. To calculate the index
********************************************************************************************************************************************
*first, the file with fortnightly food expenditures

use "$dataloc\data\pslmL1_3.dta", clear
rename serialno itc
drop if itc==1108|  itc==1109 | itc==1205 | itc==1309 | itc==1310 | itc==1402  /* other items are excluded */
drop if itc==1509 | itc==1510 | itc==1608 
drop if itc>=1900 & itc<=1903
drop if itc>=1000 & itc<=1003
drop if itc>=2000

table itc, c(n paid_q)
egen quint=rsum(paid_q wage_q own_q tran_q)
egen value=rsum(paid_v wage_v own_v tran_v)
keep if (quint>0 &  quint~=.) & (value>0 & value~=.)
keep hhcode itc quint value psucode

* to calculate the implicit price
* first check if any food item is repeated for a single household

sort hhcode itc
quietly by hhcode itc: gen dup=cond(_N==1,0,_n)
tab dup

*tabulating dup shows that dup=0 always for this file, thus no repetition

gen double ph=value/quint
label var value "Expenditure per item"
label var quint "Quantity consumed per item" 
label var ph "Implicit price per food item per household"
drop dup
gen fort=1
label var fort "=1 if fortnightly, 0 monthly"
compress
save "$dataloc\data\price\paasche1F_fbs.dta", replace

**********************************************
*Now, the file with monthly food expenditures
**********************************************

use "$dataloc\data\pslmL1_3.dta", clear
rename serialno itc
drop if itc<2000
drop if itc==2105 | itc==2206 | itc==2304 | itc==2403 | itc==2506  /* drop others */
drop if itc>2700                                                                               /* drop fuels */
drop if itc>=2000 & itc<=2002						       /* drop aggregates */
drop if itc==2605 | itc==2606						       /* drop items without quanitities */

table itc, c(n paid_q)
egen quint=rsum(paid_q wage_q own_q tran_q)
egen value=rsum(paid_v wage_v own_v tran_v)
keep if (quint>0 &  quint~=.) & (value>0 & value~=.)
keep hhcode itc quint value psucode

* to calculate the implicit price
* first check if any food item is repeated for a single household

sort hhcode itc
quietly by hhcode itc: gen dup=cond(_N==1,0,_n)
tab dup

*tabulating dup shows that dup=0 always for this file also, thus no repetition

gen double ph=value/quint
label var value "Expenditure per item"
label var quint "Quantity consumed per item" 
label var ph "Implicit price per food item per household"
drop dup
gen fort=0
label var fort "=1 if fortnightly, 0 monthly"
compress
save "$dataloc\data\price\paasche1M_fbs.dta", replace

append using "$dataloc\data\price\paasche1F_fbs.dta"
sort hhcode itc
*This file contains both monthly (fort=0) and fortnightly (fort=1) food expenditures
*check for duplicate items for a single hh by generating "dup" as before 
*no duplication found

gen valuadj=value
replace valuadj=2*value if fort==1
label var valuadj "(monthly) expend for item j per household"
notes valuadj: value if fort 0, 2*value if fort 1
compress

egen double valuet=sum(valuadj), by(hhcode)
label var valuet "Total (monthly) expend per household"

save "$dataloc\data\price\paasche1I_fbs.dta", replace

use "$dataloc\data\price\paasche1I_fbs.dta", clear

***************************************************************
* Need to compute 
*   1. total (monthly) expenditure per PSU *
*   2. expenditure for item j per PSU *
*   3. compute psu median prices for each PSU
**************************************************************
egen double valuet2=sum(valuadj), by(psucode)
egen double valuadj2=sum(valuadj), by(psucode itc)
egen double ppsu=median(ph), by(psucode itc)
egen tag=tag(psucode itc)
keep if tag==1 /* keep 1 obs for each item and psucode */

gen double wi2=valuadj2/valuet2

summ
drop hhcode tag valuadj valuet
rename valuet2 valuet
label var valuet "Total (monthly) expend per psu"

rename valuadj2 valuadj
label var valuadj "(monthly) expend for item j per psu"

rename wi2 wi
label var wi "Share of item in PSU-total expenditure"

label var ppsu "psu median price for item i"
compress
sort psucode itc

drop fort
save temp1, replace

**************************************************************
* to calculate the price of each food item at a national level
**************************************************************
set more off
use "$dataloc\data\price\paasche1I_fbs.dta", clear	
drop quint value valuadj fort
egen double p0=median(ph), by(itc)
label var p0 "Price of each food item (national/median)"
sort psucode itc
save temp2, replace
merge psucode itc using temp1
tab _m
drop _m
******************************************************
* analysis on unit values (very likely that many
* households misreported the units)
******************************************************
gen dum=(p0/ppsu>100)
gen dum2=(p0/ph>100)
egen n_ph=count(ph), by (psucode itc)
label var dum "1 if p0/ppsu>100"
label var dum2 "1 if p0/ph>100"

gen hhno=hhcode-psucode*100

gen itc2=itc if dum==1
gen itc3=itc if dum2==1
format hhcode %10.0f
capture log close
log using "$dataloc\data\price\outlier_p.smcl", replace
table itc, c(min n_ph median n_ph max n_ph)
tab dum
tab dum2
bysort itc2: table psucode if dum==1, c(min ph median ph m p0 sum dum2 n ph )
sort itc2 psucode hhno
list itc2 psucode hhno ph p0 if dum2==1 & itc2~=.
log close
browse itc2 psucode hhno ph p0 if dum2==1 & itc2~=.
