clear
set mem 200m
set more off
capture log close
global dataloc="C:\Documents and Settings\wb236343\My Documents\Pakistan\PSLM\data 2004-05"

log using "$dataloc\data\price\paasche_fbs.log", replace

*******************************************************************************************************************************************
* This program is used to do the same spatial price adjustment as "Poverty in the 1990s" *
** Program to calculate the Paasche Index by household
** 1. To obtain the budget share of each food item per household
** 2. To obtain the implicit price paid for each food item per household
** 3. To obtain the reference price (price of each food item at a national level), take the median not the mean
** 4. To calculate the index
********************************************************************************************************************************************
*first, the file with fortnightly food expenditures

use "$dataloc\data\pslmL1_3.dta", clear
rename serialno itc
drop if itc==1108|  itc==1109 | itc==1205 | itc==1309 | itc==1310 | itc==1402  /* other items are excluded */
drop if itc==1509 | itc==1510 | itc==1608 
drop if itc>=1900 & itc<=1903
drop if itc>=1000 & itc<=1003
drop if itc>=2000

table itc, c(n paid_q)
egen quint=rsum(paid_q wage_q own_q tran_q)
egen value=rsum(paid_v wage_v own_v tran_v)
keep if (quint>0 &  quint~=.) & (value>0 & value~=.)
keep hhcode itc quint value psucode

* to calculate the implicit price
* first check if any food item is repeated for a single household

sort hhcode itc
quietly by hhcode itc: gen dup=cond(_N==1,0,_n)
tab dup

*tabulating dup shows that dup=0 always for this file, thus no repetition

gen double ph=value/quint
label var value "Expenditure per item"
label var quint "Quantity consumed per item" 
label var ph "Implicit price per food item per household"
drop dup
gen fort=1
label var fort "=1 if fortnightly, 0 monthly"
compress
save "$dataloc\data\price\paasche1F_fbs.dta", replace

**********************************************
*Now, the file with monthly food expenditures
**********************************************

use "$dataloc\data\pslmL1_3.dta", clear
rename serialno itc
drop if itc<2000
drop if itc==2105 | itc==2206 | itc==2304 | itc==2403 | itc==2506  /* drop others */
drop if itc>2700                                                                               /* drop fuels */
drop if itc>=2000 & itc<=2002						       /* drop aggregates */
drop if itc==2605 | itc==2606						       /* drop items without quanitities */

table itc, c(n paid_q)
egen quint=rsum(paid_q wage_q own_q tran_q)
egen value=rsum(paid_v wage_v own_v tran_v)
keep if (quint>0 &  quint~=.) & (value>0 & value~=.)
keep hhcode itc quint value psucode

* to calculate the implicit price
* first check if any food item is repeated for a single household

sort hhcode itc
quietly by hhcode itc: gen dup=cond(_N==1,0,_n)
tab dup

*tabulating dup shows that dup=0 always for this file also, thus no repetition

gen double ph=value/quint
label var value "Expenditure per item"
label var quint "Quantity consumed per item" 
label var ph "Implicit price per food item per household"
drop dup
gen fort=0
label var fort "=1 if fortnightly, 0 monthly"
compress
save "$dataloc\data\price\paasche1M_fbs.dta", replace

append using "$dataloc\data\price\paasche1F_fbs.dta"
sort hhcode itc
*This file contains both monthly (fort=0) and fortnightly (fort=1) food expenditures
*check for duplicate items for a single hh by generating "dup" as before 
*no duplication found

gen valuadj=value
replace valuadj=2*value if fort==1
label var valuadj "(monthly) expend for item j per household"
notes valuadj: value if fort 0, 2*value if fort 1
compress

egen double valuet=sum(valuadj), by(hhcode)
label var valuet "Total (monthly) expend per household"

save "$dataloc\data\price\paasche1I_fbs.dta", replace

use "$dataloc\data\price\paasche1I_fbs.dta", clear

***************************************************************
* Need to compute 
*   1. total (monthly) expenditure per PSU *
*   2. expenditure for item j per PSU *
*   3. compute psu median prices for each PSU
**************************************************************
egen double valuet2=sum(valuadj), by(psucode)
egen double valuadj2=sum(valuadj), by(psucode itc)
egen double ppsu=median(ph), by(psucode itc)
egen tag=tag(psucode itc)
keep if tag==1 /* keep 1 obs for each item and psucode */

gen double wi2=valuadj2/valuet2

summ
drop hhcode tag valuadj valuet
rename valuet2 valuet
label var valuet "Total (monthly) expend per psu"

rename valuadj2 valuadj
label var valuadj "(monthly) expend for item j per psu"

rename wi2 wi
label var wi "Share of item in PSU-total expenditure"

label var ppsu "psu median price for item i"
compress
sort itc

drop fort
save "$dataloc\data\price\paasche1_fbs.dta", replace

**************************************************************
* to calculate the price of each food item at a national level
**************************************************************

use "$dataloc\data\price\paasche1I_fbs.dta", clear	
drop quint value valuadj fort
egen double p0=median(ph), by(itc)
label var p0 "Price of each food item (national/median)"
egen tag=tag(itc)
keep if tag==1
compress
keep itc p0
sort itc

save "$dataloc\data\price\paasche2_fbs.dta", replace

use "$dataloc\data\price\paasche1_fbs.dta", clear
merge  itc using "$dataloc\data\price\paasche2_fbs.dta"
sort psucode itc
tab _merge
drop _merge

gen double lnindex= wi*(p0/ppsu)
collapse (sum) lnindex, by(psucode)

gen psuindex=1/lnindex
label var lnindex "sum (over items) wi*(p0/ppsu)"
label var psuindex "Paasche Index by psu (FBS 2003)"
sort psucode 
summ
save "$dataloc\data\price\paasche_fbs.dta", replace

** We have prices for 16040 HHs. From the roster in PIHS/plist, there are 16182 HHs; 
** from files sect6a and sect6b in HIES/Section6, there are 16055 HHs who report any monthly
** or fortnightly consumption. We take 16055 as the entire universe for expenditure calculation 
** for the remaining (16055-16040=10) HHs, we will assign the average Paasche Index of their PSU

* The following program creates the roster of HHs (with corresponding PSUs) which reported
* fortnightly or monthly expenditures

* to obtain psucode and hhsize *
use "$dataloc\data\pslmB.dta", clear
keep hhcode serialno age
gen adult=0.8 if age<18
recode adult .=1
collapse (sum) eqadults=adult (count) hhsize=serialno, by(hhcode)
label var eqadults "Number of equivalent adults counting members & nonmembers"
label var hhsize "Number of people in hh counting members & nonmembers"
compress
sort hhcode
save temp, replace

use "$dataloc\data\pslmB.dta", clear
keep hhcode psucode province urbrural
egen tag=tag(hhcode)
keep if tag==1
sort hhcode
merge hhcode using temp
tab _m
drop _m
sort psucode
save temp1, replace

* weight *
use "$dataloc\data\weight.dta", clear
sort psucode
save temp2, replace

* Complete Passche-fbs index *
use "$dataloc\data\price\paasche_fbs.dta", clear
merge psucode using temp1
sort hhcode
tab _merge
drop _merge
sort psucode
merge psucode using temp2
tab _m
drop _m
sort hhcode
summ hhcode psuindex [aw=weight]
keep  hhcode psucode psuindex weight province urbrural

* normalized by weighted country average psuindex *
summ psuindex [aw=weight]
gen norm=_result(3)
replace psuindex=psuindex/norm
label var psuindex "Paasche-Ind by psu (normalized by country avg using 'weight') FBS2003 "

sort hhcode

table province urbrural [iweight=weight], c(mean psuindex) row col

save "$dataloc\data\price\PIndex_fbs.dta", replace

*This file has unweighted Paasche indices for 16055 HHs out of 16182 HHs in plist"

log close

*1) Even though the weights in the sample are the inverse of prob. of selection (pweights)
*aweights are fine in summary command; summ command does not allow pweights, and the mean
*reported in summ with aweights is identical to svymean (estimate of pop. mean)reported
*with pweights
*2) Since the table reports only means, which are computed in the same way as those in 
*the case of summ, aweights and pweights are identical here and so, it turns out, is iweight 
*For more details, go to http://www.stata.com/support/faqs/stat/supweight.html
