capture log close
log using do\mkf_labels.log, replace
clear

*****************************************************************
*   DATE    : September 2006
*   PROGRAM : mkf_labels  
*   AUTHOR  : Niels Lund
*   INFILE  : pslm_b.dta, pslm_c.dta, pslm_d.dta, plsm_e.dta, pslm_f, pslm_g.dta, pslm_h, pslm_i, pslm_j
*   PURPOSE : Add labels to district level PSLM files (QWIC) and 
*			save in new files according to section in questionnarie
*****************************************************************
set more 1
# delimit ;

lab define yesno
1	"Yes"
2	"No";

* small program to change yes/no=1/2 to 1/0;

cap program drop zeroone;
program zeroone;
	gen temp = 1 if `1' ==1;
	replace temp = 0 if `1'==2;
	drop `1';
	rename temp `1';
	lab val `1' yesno;
end;

* Labels on basic household information;

use "raw data/pslm_B.dta";

lab define yesno
1	"Yes"
2	"No";

lab var province "Province";
lab define province 
1	"Punjab"
2	"Sindh"
3	"NWFP"
4	"Balochistan";
lab value province province;

lab var urbrural "Urban/Rural";
lab define urbrural 
1 	"Urban" 
2 	"Rural";
lab value urbrural urbrural;

lab var psucode "Primary Sampling Unit Code";
lab var sectname "Sector name";
lab var serialno "Serial number";
lab var hhcode "Household number";

lab var sex "Gender";
lab define sex
1	"Male"
2	"Female";
lab value sex sex;

lab var res "Residing in household?";
lab define res
1	"Present"
2	"Temporarily absent";
lab value res res;

lab var rel "Relation to head of household";
lab define rel
1	"Head"
2	"Spouse"
3	"Child"
4	"Grandchild"
5	"Parent"
6	"Brother/Sister"
7	"Son/Daughter in law"
8	"Father/Mother in law"
9	"Other relative"
0	"Not related";
lab value rel rel;

lab var age "Age (in years)";

lab var marital "Marital status";
lab define marital
1	"Never married"
2	"Married"
3	"Divorced"
4	"Widowed"
5	"Only Nikah Solemnized";
lab value marital marital;

compress;
sort psucode hhcode serialno;
save basic, replace;

* labels on education data;

use "raw data/pslm_c.dta";

lab define yesno
1	"Yes"
0	"No";

lab var province "Province";
lab define province 
1	"Punjab"
2	"Sindh"
3	"NWFP"
4	"Balochistan";
lab value province province;

lab var urbrural "Urban/Rural";
lab define urbrural 
1 	"Urban" 
2 	"Rural";
lab value urbrural urbrural;

lab var psucode "Primary Sampling Unit Code";
lab var sectname "Sector name";
lab var serialno "Serial number";
lab var hhcode "Household number";

zeroone c01;
lab var c01 "Does individual read and write with understanding?";

zeroone c02;
lab var c02 "Can individual do simple arithmetic?";

zeroone c03;
lab var c03 "Has individual ever attended school?";

lab var c04 "Highest level of education completed";
lab define c04
0	"Less than class 1"
1	"Class 1"
2	"Class 2"
3	"Class 3"
4	"Class 4"
5	"Class 5"
6	"Class 6"
7	"Class 7"
8	"Class 8"
9	"Class 9"
10	"Class 10"
11	"F.A/F.Sc/C.Com/Diploma"
12	"B.A/B.Sc (except engineer, medical, comp.sci, agricultural)"
13	"Degree in engineering"
14	"Degree in medicine"
15	"Degree in computer science"
16	"Degree in agriculture"
17	"M.A/M.Sc"
18	"M.Phil/Ph.D"
19	"Other";
lab value c04 c04;

zeroone c05;
lab var c05 "Does individual currently attend school?";

lab var c06 "Class/level currently attending";
lab value c06 c04;

lab var c07 "Type of educational institution currently attending";
lab define c07
1	"Government"
2	"Masjid school"
3	"Private school"
4	"Deeni Madrasa"
5	"NGO/Trust etc"
6	"NFBE School"
7	"Privately"
8 	"Other";
lab value c07 c07;

lab var c81 "Current problems with educational institution (problem 1)";
lab var c82 "Current problems with educational institution (problem 2)";
lab define c8
1	"No problem (satisfied)"
2	"Lack of teachers"
3	"Lack of books etc"
4	"Poor teaching"
5	"Too far away"
6	"Too expensive"
7	"No toilet/water";
lab val c81 c8;
lab val c82 c8;

lab var c91 "Reason for not attending educational institution (reason 1)";
lab var c92 "Reason for not attending educational institution (reason 2)";
lab define c9
1	"Too young/too old"
2	"Education completed"
3	"Too expensive"
4	"Too far away"
5	"Had to help at home"
6	"Had to help - work"
7	"Education is not useful"
8	"Sick/handicapped"
9	"Marriage/pregnancy"
10	"Due to job/work"
11	"Poor quality of school/staff"
12	"Lack of male/female teachers"
13	"Parents do not approve"
14	"Child not willing"
15	"Other";
lab val c91 c9;
lab val c92 c9;

* recoding unknown values to "other";
replace c91=15 if c91==0|c91>15&c91!=.;
replace c92=15 if c92==0|c92>15&c92!=.;

order  province urbrural hhcode psucode sectname serialno c01 c02 c03 c04 c05 c06 c07 c81 c82 c91 c92;

compress;
sort psucode hhcode serialno;
save education, replace;

* labels on health;

use "raw data/pslm_d.dta";

lab define yesno
1	"Yes"
0	"No";

lab var province "Province";
lab define province 
1	"Punjab"
2	"Sindh"
3	"NWFP"
4	"Balochistan";
lab value province province;

lab var urbrural "Urban/Rural";
lab define urbrural 
1 	"Urban" 
2 	"Rural";
lab value urbrural urbrural;

lab var psucode "Primary Sampling Unit Code";
lab var sectname "Sector name";
lab var serialno "Serial number";
lab var hhcode "Household number";

zeroone d01;
lab var d01 "Was individual sick or injured during last two weeks?";

zeroone d02;
lab var d02 "Did individual consult anyone for this illness?";

lab var d03 "Type of health provider visited";
lab define d03
1	"Private dispensary/hospital"
2	"Public dispensary/hospital"
3	"BHU/RHC"
4	"LHV/LHW"
5	"Hakeem/Herbalist"
6	"Homeopath"
7	"Chemist/Pharmacy"
8	"Saina/Saini"
9	"Other";
lab val d03 d03;

lab var d04 "How many times did individual use health services (two weeks)?";
replace d04=. if d04>20;

lab var d51 "Problem encountered during health visit (problem 1)";
lab var d52 "Problem encountered during health visit (problem 2)";
lab define d5
1	"No problem (satisfied)"
2	"No doctor"
3	"Staff not helpful"
4	"No female staff"
5	"Not clean"
6	"Long wait"
7	"Too expensive"
8	"No trained staff"
9	"No medicine available"
10	"Unsuccessful treatment"
11	"Other";
lab val d51 d5;
lab val d52 d5;

* recoding unknown values to "other";
replace d51 =11 if d51 >11 &d51 !=.;
replace d51=. if d51==0;
replace d52 =11 if d52 >11 &d52 !=.;
replace d52=. if d52==0;

lab var d61 "Reason for not seeking medical care during last two weeks (reason 1)";
lab var d62 "Reason for not seeking medical care during last two weeks (reason 2)";
lab define d6
1	"No need"
2	"Too expensive"
3	"Too far away"
4	"No confidence in service"
5	"No doctor available"
6	"Staff not helpful"
7	"No female staff"
8	"Not clean"
9	"Long wait"
10	"No trained staff"
11	"No medicine available"
12	"Other";
lab val d61 d6;
lab val d62 d6;

* recoding unknown values to "other";
replace d61 =12 if d61 >12 &d61 !=.;
replace d61=. if d61==0;
replace d62 =12 if d62 >12 &d62 !=.;
replace d62=. if d62==0;

replace d7=. if d7>2;
zeroone d7;
lab var d7 "Has any Lady Health Worker visited household during the last 30 days?";

replace d8 = . if d8>=3;
zeroone d8;
lab var d8 "Has any household member visited the Health House during the last 30 days?";
lab val d8 yesno;

order province urbrural hhcode psucode sectname serialno d01 d02 d03 d04 d51 d52 d61 d62 d7 d8;

compress;
sort psucode hhcode serialno;
save health, replace;

* labels on household assets;

use "raw data/pslm_f.dta";

lab define yesno
1	"Yes"
0	"No";

rename prov province;
lab var province "Province";
lab define province 
1	"Punjab"
2	"Sindh"
3	"NWFP"
4	"Balochistan";
lab value province province;

rename region urbrural;
replace urbrural=. if urbrural==0;
lab var urbrural "Urban/Rural";
lab define urbrural 
1 	"Urban" 
2 	"Rural";
lab value urbrural urbrural;

rename psu psucode;
lab var psucode "Primary Sampling Unit Code";
lab var sectname "Sector name";
lab var serialno "Serial number";
lab var hhcode "Household number";

zeroone f1a;
lab var f1a "Owns land";

lab var f1b "Landownership in acres";

lab define moreless
1	"Less now"
2	"Same now"
3	"More now"
4	"Don't know";

lab define moreless1
-1	"Less now"
0	"Same now"
1	"More now";

lab val f1c moreless;
lab var f1c "Owned land: More or less compared to 1 year age";

recode f1c (1=-1) (2=0) (3=1) (4=.) , gen(f1c_bis);
lab var f1c_bis "Owned land: More or less compared to 1 year ago";
lab val f1c_bis moreless1;


zeroone f1d;
lab var f1d "Owned land: Is this land mainly irrigated?";

zeroone f2a;
lab var f2a "Do you rent out land?";

lab var f2b "Land rented out (in acres)";

lab val f2c moreless;
lab var f2c "Land rented out: More or less compared to 1 year ago";

recode f2c (1=-1) (2=0) (3=1) (4=.) , gen(f2c_bis);
lab var f2c_bis "Land rented out: More or less compared to 1 year ago";
lab val f2c_bis moreless1;

zeroone f2d;
lab var f2d "Land rented out: Is this land mainly irrigated?";

zeroone f2e;
lab var f2e "Is land rented out on a fixed rent basis?";

zeroone f2f;
lab var f2f "Is land rented out on a sharecropping basis?";

zeroone f3a;
lab var f3a "Have you rented agricultural land?";

lab var f3b "Land rented (in acres)";

lab val f3c moreless;
lab var f3c "Rented land: More or less compared to 1 year ago";

recode f3c (1=-1) (2=0) (3=1) (4=.) , gen(f3c_bis);
lab var f3c_bis "Rented land: More or less compared to 1 year ago";
lab val f3c_bis moreless1;

zeroone f3d;
lab var f3d "Rented land: Is land mainly irrigated?";

zeroone f3e;
lab var f3e "Is land rented on a fixed rent basis?";

zeroone f3f;
lab var f3f "Is land rented on a sharecropping basis?";

zeroone f4a;
lab var f4a "Own cattle";
lab var f4b "Number of cattle";
lab val f4c moreless;
lab var f4c "Cattle: More or less compared to 1 year ago";

recode f4c (1=-1) (2=0) (3=1) (4=.) , gen(f4c_bis);
lab var f4c_bis "Cattle: More or less compared to 1 year ago";
lab val f4c_bis moreless1;

zeroone f5a;
lab var f5a "Own sheep/goats";
lab var f5b "Number of sheep/goats";
lab val f5c moreless;
lab var f5c "Sheep/goats: More or less compared to 1 year ago";

recode f5c (1=-1) (2=0) (3=1) (4=.) , gen(f5c_bis);
lab var f5c_bis "Sheep/goats: More or less compared to 1 year ago";
lab val f5c_bis moreless1;

zeroone f6a;
lab var f6a "Own laden animals";
lab var f6b "Number of laden animals";
lab val f6c moreless;
lab var f6c "Laden animals: More or less compared to 1 year ago";

recode f6c (1=-1) (2=0) (3=1) (4=.) , gen(f6c_bis);
lab var f6c_bis "Laden animals: More or less compared to 1 year ago";
lab val f6c_bis moreless1;

zeroone f7a;
lab var f7a "Own poultry";
lab var f7b "Number of poultry";
lab val f7c moreless;
lab var f7c "Poultry: More or less compared to 1 year ago";

recode f7c (1=-1) (2=0) (3=1) (4=.) , gen(f7c_bis);
lab var f7c_bis "Poultry: More or less compared to 1 year ago";
lab val f7c_bis moreless1;

zeroone f8a;
lab var f8a "Do you own non-agricultural land?";

lab var f8b "Non-agriculatural land (in square yards)";

lab val f8c moreless;
lab var f8c "Non-agriculatural land: More or less compared to 1 year ago";

recode f8c (1=-1) (2=0) (3=1) (4=.) , gen(f8c_bis);
lab var f8c_bis "Non-agricultural land: More or less compared to 1 year ago";
lab val f8c_bis moreless1;

lab define zone
1	"Urban"
2	"Semi-urban"
3	"Rural";
lab val f8d zone;
lab var f8d "Zone for non-agricultural land";

lab var f8e "Non-agriculatural land: Expected value (rs)";

zeroone f9a;
lab var f9a "Do you own residential buildings?";

lab var f9b "Residential buildings (in square feet)";

lab val f9c moreless;
lab var f9c "Residential buildings: More or less compared to 1 year ago";

recode f9c (1=-1) (2=0) (3=1) (4=.) , gen(f9c_bis);
lab var f9c_bis "Residential buildings: More or less compared to 1 year ago";
lab val f9c_bis moreless1;

lab val f9d zone;
lab var f9d "Zone for residential buildings";

lab var f9e "Residential buildings: Expected value (rs)";

zeroone f10a;
lab var f10a "Do you own shop/commercial buildings?";

lab var f10b "Shop/commercial buildings (in square feet)";

lab val f10c moreless;
lab var f10c "Shop/commercial buildings: More or less compared to 1 year ago";

recode f10c (1=-1) (2=0) (3=1) (4=.) , gen(f10c_bis);
lab var f10c_bis "Shop/commercial buildings: More or less compared to 1 year ago";
lab val f10c_bis moreless1;

lab val f10d zone;
lab var f10d "Zone for shop/commercial buildings";

lab var f10e "Shop/commercial buildings: Expected value (rs)";

zeroone f11a;
zeroone f11b;
zeroone f11c;
zeroone f11d;
zeroone f11e;
zeroone f11f;
zeroone f11g;
zeroone f11h;
zeroone f11i;
zeroone f11j;
zeroone f11k;
zeroone f11l;
zeroone f11m;
zeroone f11n;
zeroone f11o;
zeroone f11p;

lab var f11a "Owns electric iron";
lab var f11b "Owns electric fan";
lab var f11c "Owns sewing machine";
lab var f11d "Owns radio or cassette player";
lab var f11e "Owns chair/table";
lab var f11f "Owns watch/clock";
lab var f11g "Owns television";
lab var f11h "Owns VCP/VCR/CD player";
lab var f11i "Owns refrigerator";
lab var f11j "Owns air cooler";
lab var f11k "Owns air conditioner";
lab var f11l "Owns computer";
lab var f11n "Owns bicycle";
lab var f11m "Owns motorcycle";
lab var f11o "Owns car/truck";
lab var f11p "Owns tractor";

lab define situation
1	"Much worse now"
2	"A little worse now"
3	"Same"
4	"A little better now"
5	"Much better now"
6	"Don't know";
lab val f12 situation;
lab var f12 "Economic situation of household compared to 1 year ago";

recode f12 (1=-2) (2=-1) (3=0) (4=1) (5=2) (6=.) , gen(f12_bis);
lab var f12_bis "Economic situation of household compared to 1 year ago";

lab val f13 situation;
lab var f13 "Economic situation of community compared to 1 year ago";

recode f13 (1=-2) (2=-1) (3=0) (4=1) (5=2) (6=.) , gen(f13_bis);
lab var f13_bis "Economic situation of community compared to 1 year ago";

order   province stratum urbrural psucode hhcode sectname serialno 
f1a f1b f1c f1c_bis f1d f2a f2b f2c f2c_bis f2d f2e f2f f3a f3b f3c f3c_bis f3d f3e f3f 
f4a f4b f4c f4c_bis f5a f5b f5c f5c_bis f6a f6b f6c f6c_bis f7a f7b f7c f7c_bis 
f8a f8b f8c f8c_bis f8d f8e f9a f9b f9c f9c_bis f9d f9e f10a f10b f10c f10c_bis f10d f10e 
f11a f11b f11c f11d f11e f11f f11g f11h f11i f11j f11k f11l f11m f11n f11o f11p f12 f12_bis f13 f13_bis;

compress;
sort psucode hhcode serialno;
save assets, replace;

* labels on household characteristics;

use "raw data/pslm_g.dta";

lab define yesno
1	"Yes"
0	"No";

lab var province "Province";
lab define province 
1	"Punjab"
2	"Sindh"
3	"NWFP"
4	"Balochistan";
lab value province province;

lab var urbrural "Urban/Rural";
lab define urbrural 
1 	"Urban" 
2 	"Rural";
lab value urbrural urbrural;

lab var psucode "Primary Sampling Unit Code";
lab var sectname "Sector name";
lab var serialno "Serial number";
lab var hhcode "Household number";

lab var g01 "Present occupancy status";
lab define g01
1	"Owner occupied"
2	"Rented"
3	"Subsidized rented"
4	"Rent free";
lab val g01 g01;

lab var g02 "Number of rooms in dwelling";

lab var g03 "Roof material";
lab define g03
1	"RCC/RBC"
2	"Wood/Bamboo"
3	"Steel/Cement sheets"
4	"Other";
lab val g03 g03;

lab var g04 "Material used in walls";
lab define g04
1	"Burnt bricks/blocks"
2	"Mud/mud bricks"
3	"Wood/Bamboo"
4	"Stones"
5	"Other";
lab val g04 g04;

lab var g05 "Main source of drinking water";
lab define g05
1	"Piped into house/compound"
2	"Outdoor tap"
3	"Hand pump"
4	"Motorized pump"
5	"Covered well"
6	"Unprotected well"
7	"River, stream, pond, lake"
8	"Water tanker/truck or vendor"
9	"Other";
lab val g05 g05;

lab var g06 "Type of toilet facility";
lab define g06
1	"None"
2	"Flush system - linked w/sewage"
3	"Flush system - linked w/septic tank"
4	"Flush system - open drain"
5	"Raised latrine (khadi)"
6	"Pit latrine"
7	"Other";
lab val g06 g06;

lab var g07 "Source of fuel for cooking";
lab define g07
1	"Wood"
2	"Gas"
3	"Kerosine"
4	"Dung cake"
5	"Electricity"
6	"Crop residue"
7	"Charcoal/coal"
8	"Other";
lab val g07 g07;

lab var g08 "Source of fuel for lighting";
lab define g08
1	"Wood"
2	"Gas"
3	"Kerosine"
4	"Fire wood"
5	"Candles"
6	"Other";
lab val g08 g08;

lab var g09 "Phone in working condition?";
lab define g09
1	"No"
2	"Land line only"
3	"Mobile only"
4	"Both land line and mobile";
lab val g09 g09;

lab var g10a1 "Time spent reaching drinking water (minutes)";
lab var g10a2 "Means of transportation for reaching drinking water";

lab var g10b1 "Time spent reaching groceries (minutes)";
lab var g10b2 "Means of transportation for reaching groceries";

lab var g10c1 "Time spent reaching public transport (minutes)";
lab var g10c2 "Means of transportation for reaching public transport";

lab var g10d1 "Time spent reaching primary school (minutes)";
lab var g10d2 "Means of transportation for reaching primary school";

lab var g10e1 "Time spent reaching middle school (minutes)";
lab var g10e2 "Means of transportation for reaching middle school";

lab var g10f1 "Time spent reaching high school (minutes)";
lab var g10f2 "Means of transportation for reaching high school";

lab var g10g1 "Time spent reaching health clinic (minutes)";
lab var g10g2 "Means of transportation for reaching health clinic";

lab var g10h1 "Time spent reaching family planning center (minutes)";
lab var g10h2 "Means of transportation for reaching family planning center";

lab define minutes
1	"0-14"
2	"15-29"
3	"30-44"
4	"45-59"
5	"60+";

lab define transport
1	"By foot"
2	"Non-machinery"
3	"Machinery";

lab val g10a1 minutes;
lab val g10b1 minutes;
lab val g10c1 minutes;
lab val g10d1 minutes;
lab val g10e1 minutes;
lab val g10f1 minutes;
lab val g10g1 minutes;
lab val g10h1 minutes;

lab val g10a2 transport;
lab val g10b2 transport;
lab val g10c2 transport;
lab val g10d2 transport;
lab val g10e2 transport;
lab val g10f2 transport;
lab val g10g2 transport;
lab val g10h2 transport;

compress;
sort psucode hhcode serialno;
save household, replace;

* labels on immunization and diarrhoea;

use "raw data/pslm_i.dta";

lab define yesno
1	"Yes"
0	"No";

lab var province "Province";
lab define province 
1	"Punjab"
2	"Sindh"
3	"NWFP"
4	"Balochistan";
lab value province province;

lab var urbrural "Urban/Rural";
lab define urbrural 
1 	"Urban" 
2 	"Rural";
lab value urbrural urbrural;

lab var psucode "Primary Sampling Unit Code";
lab var sectname "Sector name";
lab var serialno "Serial number";
lab var hhcode "Household number";
lab var mid "Mother id no.";
lab var cid "Child id no.";

zeroone i03;
lab var i03 "Has child been immunized?";

zeroone i04;
lab var i04 "Do you have an immunization card?";

lab var i51 "Child immunization: BCG";
lab var i52 "Child immunization: DPT1";
lab var i53 "Child immunization: DPT2";
lab var i54 "Child immunization: DPT3";
lab var i55 "Child immunization: Polio 1";
lab var i56 "Child immunization: Polio 2";
lab var i57 "Child immunization: Polio 3";
lab var i58 "Child immunization: Measles";

lab define imm
1	"Yes, according to card"
2	"Yes, according to knowledge"
3	"No"
4	"Don't know";

lab val i51 imm;
lab val i52 imm;
lab val i53 imm;
lab val i54 imm;
lab val i55 imm;
lab val i56 imm;
lab val i57 imm;
lab val i58 imm;

gen bcg = 1 if i51==1|i51==2;
replace bcg = 0 if i51==3|i51==4;
lab var bcg "Immunization incidence: BCG";
lab val bcg yesno;

gen dpt1 = 1 if i52==1|i52==2;
replace dpt1 = 0 if i52==3|i52==4;
lab var dpt1 "Immunization incidence: DPT1";
lab val dpt1 yesno;

gen dpt2 = 1 if i53==1|i53==2;
replace dpt2 = 0 if i53==3|i53==4;
lab var dpt2 "Immunization incidence: DPT2";
lab val dpt2 yesno;

gen dpt3 = 1 if i54==1|i54==2;
replace dpt3 = 0 if i54==3|i54==4;
lab var dpt3 "Immunization incidence: DPT3";
lab val dpt3 yesno;

gen polio1 = 1 if i55==1|i55==2;
replace polio1 = 0 if i55==3|i55==4;
lab var polio1 "Immunization incidence: Polio 1";
lab val polio1 yesno;

gen polio2 = 1 if i56==1|i56==2;
replace polio2 = 0 if i56==3|i56==4;
lab var polio2 "Immunization incidence: Polio 2";
lab val polio2 yesno;

gen polio3 = 1 if i57==1|i57==2;
replace polio3 = 0 if i57==3|i57==4;
lab var polio3 "Immunization incidence: Polio 3";
lab val polio3 yesno;

gen measles = 1 if i58==1|i58==2;
replace measles = 0 if i58==3|i58==4;
lab var measles "Immunization incidence: Measles";
lab val measles yesno;

zeroone i06;
lab var i06 "Was child affected with diarrhea in last 30 days?";

zeroone i07;
lab var i07 "Did you consult anyone for treatment of diarrhea?";

lab var i08 "Who was consulted first?";
lab define consult
1	"Private dispensary/Hospital"
2	"Government hospital"
3	"BHU/PHC"
4	"LHW"
5	"Nurse/LHV"
6	"Chemist/Pharmacy"
7	"Hakeem, homeopathic, herbalist"
8	"Other";
lab val i08 consult;

lab var i09 "Did you give the child ORS (nimkol)";
lab define treat
1	"Yes - purchased/provided"
2	"Yes - homemade"
3	"No";
lab val i09 treat;

gen ors = 1 if i09==1|i09==2;
replace ors = 0 if i09==3;
lab var ors "Incidence of ORS use";
lab val ors yesno;

order province urbrural hhcode psucode sectname serialno mid cid year month 
i03 i04 i51 i52 i53 i54 i55 i56 i57 i58 i06 i07 i08 i09 
bcg dpt1 dpt2 dpt3 polio1 polio2 polio3 measles ors;

compress;
sort psucode hhcode serialno;
save immunization, replace;

* labels on pre- and postnatal care;

use "raw data/pslm_j.dta";

lab define yesno
1	"Yes"
0	"No";

lab var province "Province";
lab define province 
1	"Punjab"
2	"Sindh"
3	"NWFP"
4	"Balochistan";
lab value province province;

lab var urbrural "Urban/Rural";
lab define urbrural 
1 	"Urban" 
2 	"Rural";
lab value urbrural urbrural;

lab var psucode "Primary Sampling Unit Code";
lab var sectname "Sector name";
lab var serialno "Serial number";
lab var hhcode "Household number";

zeroone j01;
lab var j01 "Has given birth in last 3 years (15-49 years)";

zeroone j02;
lab var j02 "Received any pre-natal care during pregnancy of last child";

lab var j03 "Place of pre-natal care";
lab define prenatal
1	"TBA - house"
2	"LHW - house"
3	"LHV - house"
4	"Doctor - house"
5	"BHU/RHC/Govt. hospital"
6	"Private hospital"
7	"Other";
lab val j03 prenatal;

zeroone j04;
lab var j04 "Received tetanus toxoid injection";

lab var j05 "Number of tetanus toxoid injections";

lab var j06 "Place of birth";
lab define birthplace
1	"House"
2	"BHU/RHC/Govt. hospital"
3	"Private hospital"
4	"Other";
lab val j06 birthplace;

lab var j07 "Assistance at birth";
lab define assist
1	"Doctor"
2	"Nurse"
3	"Qualified midwife"
4	"DAI/TBA"
5	"Family member/neighbor/friend"
6	"Others";
lab val j07 assist;

gen trainedasst = 1 if j07==1|j07==2|j07==3|j07==4;
replace trainedasst = 0 if j07==5|j07==6;
lab val trainedasst yesno;
lab var trainedasst "Trained birth attendant";

zeroone j08;
lab var j08 "Received post-natal care within 6 months after birth";

lab var j09 "Place of post-natal care";
lab val j09 prenatal;

order province urbrural hhcode psucode sectname serialno j01 j02 j03 j04 j05 j06 j07 j08 j09;

compress;
sort psucode hhcode serialno;
save pregnancy, replace;

* labels on employment;

use "raw data/pslm_e.dta";

lab define yesno
1	"Yes"
2	"No";

lab var province "Province";
lab define province 
1	"Punjab"
2	"Sindh"
3	"NWFP"
4	"Balochistan";
lab value province province;

lab var urbrural "Urban/Rural";
lab define urbrural 
1 	"Urban" 
2 	"Rural";
lab value urbrural urbrural;

lab var psucode "Primary Sampling Unit Code";
lab var sectname "Sector name";
lab var serialno "Serial number";
lab var hhcode "Household number";

lab var e01 "Did individual work at least one hour (paid) during last week?";
lab val e01 yesno;

lab var e02 "If person did not work, does he/she have any business, shop, farm or service provider work?";
lab val e02 yesno;

lab var e03 "Did individual work without wage at family farm, business, trade etc in last week?";
lab val e03 yesno;

lab var e04 "Did individual look for work, unsuccessfully, last week?";
lab val e04 yesno;

lab var e05 "Underlying reason for no work";
lab define e05
1	"Illness/Handicap"
2	"Other constraints (pregnancy etc)"
3	"Temporarily laid off"
4	"Apprentice"
5	"Student"
6	"Housekeeping"
7	"Retired"
8	"Land lord/property owner"
9	"Too young/too old"
0	"Other";
lab val e05 e05;

lab var e06 "Why did individual not work last week?";
lab define e06
1	"Illness/injured"
2	"Strike or lockout"
3	"Holiday/leave"
4	"Off season"
5	"Bad weather"
6	"Machine breakdown"
7	"Shortage of raw material"
8	"Leave for education"
9	"Maternity leave/parental leave"
0	"Other";
lab val e06 e06;

lab var e07 "Employment status";
lab define e07
1	"Paid employee"
2	"Self employed (non-agricultural)"
3	"Own cultivator"
4	"Contract cropper"
5	"Share cropper"
6	"Unpaid, family helper"
7	"Employer"
8	"Livestock (only)";
lab val e07 e07;

lab var e08 "Type of institution where invididual works";
lab define e08
1	"Government"
2	"Private business"
3	"Private person/household"
4	"NGO"
5	"Other";
lab val e08 e08;

lab var e09 "Nature of work - profession";
lab define e09
1	"Senior official and managers"
2	"Professionals"
3	"Technicians and associate professionals"
4	"Clerks"
5	"Service, shop, sale, workers"
6	"Skilled agriculture/fishery"
7	"Craft and trade workers"
8	"Plant, machinery operators"
9	"Elementary occupations";
lab val e09 e09;

lab var e10 "Industrial sector in which the individual works";
lab define e10
1	"Agriculture, forestry, fishing"
2	"Mining and quarrying"
3	"Manufacturing"
4	"Electricity"
5	"Construction"
6	"Wholesale and retail"
7	"Transport and storage"
8	"Real estate, insurance"
9	"Social and personal services"
10	"Other";
lab val e10 e10;
replace e10=. if e10>10;

lab var e11 "Did individual work for salary/financial benefit in last month";
lab val e11 yesno;

replace e11=. if e11>2|e11==0;

lab var e12 "How many days did individual work during last month (paid)";
destring e12, replace;
replace e12=. if e12>31;

lab var e13 "Salary earned during last month (rs.)";

lab var e14 "Month employed during last year";
destring e14, replace;
replace e14=. if e14>12;

lab var e15 "Did indivual work for earning during last year?";
lab val e15 yesno;

lab var e16 "How much did individual earn during last year (rs.)";

compress;
sort psucode hhcode serialno;
save employment, replace;



# delimit cr

log close
