clear
set mem 40m

* Part-I: Extract detailed expenditure data and compute household yearly item wise health expenditure from file titled sect6c.dta.

* Noshin
* agnes DC
use "M:\Agnes\Surveys Pak\HIES-PIHS\PIHS 98-99\sect6c.dta", clear
* agnes travel
	
rename serialno itc 
rename paid_v s6cq02 
rename wage_v s6cq04 
rename own_v s6cq06 
rename tran_v s6cq08
 
* select those expenditure items from the file that are related to health. These are 5601, 5602, 5603, 5604 only.
keep if ( itc>=5601 &  itc<=5604)
*(277725 observations deleted)

	* All expenditure is considered here, whether paid and consumed, or unpaid and consumed.

recode  s6cq02 s6cq04 s6cq06 s6cq08 (miss=0)
*(s6cq02: 351 changes made)
*(s6cq04: 25645 changes made)
*(s6cq06: 25896 changes made)
*(s6cq08: 25722 changes made)


gen healthexp =  s6cq02+ s6cq04+ s6cq06+ s6cq08

gen fees =  healthexp if  (itc >5601 & itc <5603)
*(15200 missing values generated)

gen drugs =  healthexp  if  (itc <5602)
*(15153 missing values generated)

gen hospit =  healthexp  if  (itc >5602 & itc < 5604)
*(22743 missing values generated)

gen othercare =  healthexp if  (itc >5603 & itc < 5605)
*(24799 missing values generated)

gen healthm = healthexp/12

recode   fees drugs hospit othercare healthexp healthm (miss=0)
*medexp5602: 15017 changes made
*medexp5601: 15901 changes made
*medexp5603: 24531 changes made
*medexp5604: 25992 changes made

	* Aggregate all medical expenditure of the household with item wise breakup as well.

collapse (sum) healthexp healthm  fees drugs hospit othercare, by (hhcode)
sort hhcode

label variable drugs "yearly expenditure on medicines and supply"
label variable hospit "yearly expenditure on hospital care"
label variable fees "yearly expenditure on outpatient fees (incl medicines provided)"
label variable othercare "yearly expenditure on other care"
label variable healthexp "yearly expenditure on medical care"
label variable healthm "monthly expenditure on medical care"


* Here the total number of households is 14,559

save medexp.dta, replace

* Part-Ib: Merge the above file with Expendts.dta (already prepared by WB) and save new file "core".

	* consumption data.dta file contains total household expenditure along with household sizes, adult equivalent household sizes, price indices, weights etc.
	* This has 14,708 households, which is more than the number of households in our medexp.dta file created by us from sect6c.dta.

* Noshin
* agnes Travel
* agnes DC
use "M:\Agnes\Surveys Pak\HIES-PIHS\plsms0405\consumption data.dta", clear


sort hhcode
merge hhcode using medexp.dta, unique

* 149 hh with no medical expenditure
* Put zero for households who have missing values for health expenditure. 
recode   fees drugs hospit othercare healthexp healthm (miss=0)

keep  hhcode eqadults hhsize weight popwt province urbrural texpendF peaexp healthexp healthm fees drugs hospit othercare
sort hhcode
save core.dta, replace


* Part-II(a): Retrieving Information about household characteristics

	* Household composition create a people file
* Noshin
* Agnes travel
* Agnes DC
use "M:\Agnes\Surveys Pak\HIES-PIHS\plsms0405\raw data\pslmB.dta", clear
sort hhcode

*NUMBER AND PROPORTION OF CHILDREN UNDER 15 YEARS OF AGE

gen kid = 1 if  age<15
replace kid = 0 if kid ==.
by hhcode: gen nbkid = kid if _n==1
by hhcode: replace nbkid = nbkid[_n-1]+kid if _n>1
by hhcode: gen pkid = nbkid / (_N)
label variable nbkid "number of children less than 15 years of age in the household"
label variable pkid "proportion of children less than 15 years of age in the household"

* NUMBER AND PROPORTION OF ADULTS OVER 60

gen old = 1 if  age>60
replace old = 0 if old ==.
by hhcode: gen nbold = old if _n==1
by hhcode: replace nbold = nbold[_n-1]+old if _n>1
by hhcode: gen pold = nbold / (_N)
label variable  nbold "number of adults greater than 60 years of age in the household"
label variable  pold "proportion of adults greater than 60 years of age in the household"

* PROPORTION OF ADULTS (BETWEEN 15 AND 59) WHO ARE FEMALES IN HOUSEHOLD

gen fem =1 if  sex == 2 &  age>=15 & age<=60
replace fem = 0 if fem ==.
by hhcode: gen nbfem = fem if _n==1
by hhcode: replace nbfem = nbfem[_n-1]+fem if _n>1
by hhcode: gen pfemad = nbfem/ (_N)
replace pfemad=0 if pfemad==.
label variable pfemad "Proportion of 15-59 who are female in hh"
label variable nbfem  "Number of females 15-59 in hh"

* Head of household sex
gen sh =  sex if  rel==1
replace sh = 0 if sh ==.
by hhcode: gen sexhead = sh if _n==1
by hhcode: replace sexhead = max(sh, sexhead[_n-1]) if _n>1
label variable  sexhead "sex of household head"
replace sexhead=. if sexhead==0
save people.dta, replace 

********* Integrating education variables

******** literacy: get info and integrate them to the people file 
* Agnes travel

* Agnes DC
use "M:\Agnes\Surveys Pak\HIES-PIHS\plsms0405\raw data\pslmD.dta", clear
* Noshin

* In 92-93 questionnaire, literate means read and write, we use the same criteria here
* knowing that for writting only 38,402 have a yes or no response (all do for read)
* under 10 were not assessed for literacy they have and keep a missing value
* Another issue, in educatn1 4 individuals are repeated twice, they are dropped in the process
gen lit=1 if   d01==1 
sort hhcode serialno
duplicates drop
save ed1, replace
use people
sort hhcode serialno
merge  hhcode serialno using ed1, keep (lit)
drop if _merge==2
* 12 people have no response, considered non-literate by default ratehr than creating missing category
drop  _merge


* PROPORTION OF LITERATE INVIVIDUALS OVER 15 IN HOUSEHOLD

sort hhcode
gen litad=1 if  lit==1 & age>=15
replace litad=0 if lit==0
recode  litad (miss=0)
by  hhcode: gen nblitad=litad if _n==1
by hhcode: replace nblitad=nblitad[_n-1]+litad if _n>1
by hhcode: gen plitad=nblitad/(_N- nbkid)
label variable plitad "proportion of literate adults in hh"
save people.dta, replace 


* HIGHEST DIPLOMA OF ADULTS IN HOUSEHOLD

* retrieve diploma and recode it to fit HIES categories
*agnes travel
* Agnes DC
use "M:\Agnes\Surveys Pak\HIES-PIHS\plsms0405\raw data\pslmD.dta", clear
* Noshin

keep  hhcode serialno d04

* HIGHEST DIPLOMA IN HH those missing are given zero 
* this was done without checking with sbody who knows edu system, based on rough assumptions
* data looks strange and a few (7) with high numbers - which should not be given as code are considered highly eductated
gen diploma=1 if  d04<=4
replace diploma=2 if  (d04==5 | d04==6 | d04==7 )
replace diploma=3 if  (d04==8 | d04==9)
replace diploma=4 if  d04==10
replace diploma=5 if  d04==11
replace diploma=6 if  d04==12
replace diploma=7 if  d04>=13
replace diploma=0 if  d04==.
* quality of variable dubious: 7% of the pop is below primary and less than 1% above!
sort hhcode serialno
save ed1, replace
use people
sort hhcode serialno
merge  hhcode serialno using ed1, keep (diploma)
sort hhcode
gen dipl= diploma if  age>=15
replace dipl = 0 if dipl ==.

by  hhcode: gen hdipl=dipl if _n==1
by hhcode: replace hdipl=max(dipl, hdipl[_n-1]) if _n>1 
label variable hdipl "highest adult diploma in hh"
label define dipl 0 "Other or n.a." 1 "No formal edu or below primary (Less than or equal to class 4)" 2 "Primary (Class 5, 6, 7)" 3 "Middle (Class 8, 9)" 4 "Matric (Class 10,11)" 5 "Intermediate (Class 12)" 6 "BA/BSC/Polytech" 7 "Postgraduate"
label values  hdipl dipl
drop  _merge
sort hhcode serialno
save people.dta, replace 


* EMPLOYMENT VARIABLES FOR FUTURE USE
*agnes
*use "C:\Documents and Settings\wb231464\My Documents\Copy of M\Surveys Pak\HIES-PIHS\PIHS 98-99\empstat 98-99\inco_f.dta", clear
* Noshin
*use "C:\Documents and Settings\noshin.NHPU\Desktop\Agnus Catastrophic Health Expenditure\PIHS 98-99\inco_f.dta", clear


*keep   hhcode idc s1bq01 s1bq03  s1bq04 s1bq05
*sort  hhcode idc
*save empl, replace
*use people
*merge  hhcode idc using empl
*drop  _merge

************  THIS PART TO BE DRAFTED WHEN CODES AVAILABLE EMPLOYMENT, VARIABLES ARE INCLUDED BUT NOT USED YET**********


***************KEEP LAST INDIVIDUAL AND INCLUDE HH INFO IN CORE****************************

* Part-II(b): Keep last household member and allocate summary information to household

sort hhcode 
by hhcode: drop if _n<_N
keep  hhcode nbkid pkid nbold pold nbfem pfemad sexhead plitad hdipl
save lastinidv.dta, replace
merge  hhcode using core
* there are 148 hh for which we have info on eductation etc. but no info on expenditure, they are dropped
drop if  _merge==1
drop  _merge
sort hhcode
save core, replace


*****************STOP HERE TEMPORARILY PB MERGING POVERTY NOT USEFUL ANYWAY***************



* INFO FROM POVERTYFILE

*agnes Travel
*agnes DC
*
use "M:\Agnes\Surveys Pak\HIES-PIHS\plsms0405\pov0102_fbs_revised.dta", clear
* Noshin

* weight is the same as in core, we drop it
drop weight 
sort hhcode
merge  hhcode using core


********Cleaning out and renaming variables
rename  urbrural rurban
label variable rurban "Urban or Rural"
label define rurb 1 "Urban" 2 "Rural"
label values rurban rurb

rename   popwt iweight
rename weight hweight
label variable hweight "Household weight"
label variable iweight "Individual weight"

label variable eqadults "number of equivalent adults counting all"


label variable drugs "Yearly expenditure on medicines and supply "
label variable hospit "Yearly expenditure on hospital care "
label variable fees "Yearly expenditure on outpatient fees (incl medicines provided)"
label variable othercare "Yearly expenditure on other care "
label variable healthexp "Yearly expenditure on medical care "
label variable healthm "Monthly expenditure on medical care "


* HERE WE ASSIGN VALUE LABELS TO PROVINCES
label define grp 1 "Punjab" 2 "Sind" 3 "NWFP" 4 "Baluchistan" 5 "AJK" 6 "Northern Areas" 7 "FATA"
label values province grp

order   hhcode  hweight iweight   hhsize  healthm  healthexp  fees hospit drugs othercare  texpendF province rurban  sexhead nbkid pkid nbold pold nbfem pfemad plitad hdipl  eqadult peaexp 
*agnes TRavel
* Agnes DC
save "M:\Agnes\Surveys Pak\HIES-PIHS\plsms0405\PLSMrough.dta"
* Noshin
*save "C:\Documents and Settings\noshin.NHPU\Desktop\Agnus Catastrophic Health Expenditure\PIHS 98-99\HIES_98-99clean.dta",replace


